==> menu_manipulator-8.x-1.1.tar.gz: menu_manipulator/README.md <==
CONTENTS OF THIS FILE
---------------------
   
 * Introduction
 * Requirements
 * Recommended modules
 * Installation
 * Configuration
 * Troubleshooting
 * FAQ
 * Maintainers


INTRODUCTION
------------

The Menu Manipulator menu provides developers with helpful functions to 
filter menu trees in Drupal 8.

 * For a full description of the module, visit the project page:
   https://drupal.org/project/menu_manipulator

 * To submit bug reports and feature suggestions, or to track changes:
   https://drupal.org/project/issues/menu_manipulator


REQUIREMENTS
------------

This module requires the following modules:

 * Menu Link Content (in core: `menu_link_content`)

RECOMMENDED MODULES
-------------------

 * Menu UI (in core: `menu_ui`)
 * Markdown filter (https://www.drupal.org/project/markdown):
   When enabled, display of the project's README.md help will be rendered
   with markdown.


INSTALLATION
------------
 
 * Install as you would normally install a contributed Drupal module. Visit:
   https://drupal.org/documentation/install/modules-themes/modules-8
   for further information.


CONFIGURATION
-------------

This module do not do anything on its own. You must implement custom functions
and/or preprocesses in order to filter menus. See example on the module page.

This module has modifiable settings as of now. 


TROUBLESHOOTING
---------------

 * If menus are not filtered, check that you have correctly type the preprocess 
 function's name. Then, check that your theme is enabled. 

FAQ
---

Q: How do I filter a menu by current user's language?

A: Easy.
  Implement `template_preprocess_menu()` in your theme.
  Then use this custom function to filter menu items:
  `menu_manipulator_get_multilingual_menu($menu_name)`.

  You can find code example in `menu_manipulator.module` file.


MAINTAINERS
-----------

Current maintainers:
 * Matthieu Scarset (matthieuscarset) - https://www.drupal.org/user/3471281/

This project has not been sponsored (yet).

==> menu_manipulator-8.x-2.0.tar.gz: menu_manipulator/README.md <==
CONTENTS OF THIS FILE
---------------------
   
 * Introduction
 * Requirements
 * Recommended modules
 * Installation
 * Configuration
 * Troubleshooting
 * FAQ
 * Maintainers


INTRODUCTION
------------

The Menu Manipulator menu provides site builders with automatic
filtering of menu item. Developers also have a new helpful service
to filter menu trees in Drupal 8.

 * For a full description of the module, visit the project page:
   https://drupal.org/project/menu_manipulator

 * To submit bug reports and feature suggestions, or to track changes:
   https://drupal.org/project/issues/menu_manipulator


REQUIREMENTS
------------

This module requires the following modules:

 * Menu Link Content (in core: `menu_link_content`)

RECOMMENDED MODULES
-------------------

 * Menu UI (in core: `menu_ui`)
 * Markdown filter (https://www.drupal.org/project/markdown):
   When enabled, display of the project's README.md help will be rendered
   with markdown.


INSTALLATION
------------
 
 * Install as you would normally install a contributed Drupal module. Visit:
   https://drupal.org/documentation/install/modules-themes/modules-8
   for further information.


CONFIGURATION
-------------

This module automatically filter menus. You must enable the custom functions
under Admin > Configuration > User Interface > Menu manipulator settings.


TROUBLESHOOTING
---------------

 * If menus are not filtered, check configuration in the admin setting page.

FAQ
---

Q: How does the magic happen?

A: Easy. There's a new service `menu_manipulator.menu_tree_manipulators`
  that is used to apply filters upon Menu Trees before rendering.

  We have created a custom method to automatically filter by language.
  
  You can find code example in `menu_manipulator.module` file.


MAINTAINERS
-----------

Current maintainers:
 * Matthieu Scarset (matthieuscarset) - https://www.drupal.org/user/3471281/

This project has not been sponsored - yet.
